@font-face{font-family:ccw;src:url(../fonts/ccw.eot);src:url(../fonts/ccw.eot#iefix) format('embedded-opentype'),url(../fonts/ccw.ttf) format('truetype'),url(../fonts/ccw.woff) format('woff'),url(../fonts/ccw.svg#ccw) format('svg');font-weight:400;font-style:normal}.ctc-icon{font-family:ccw!important;speak:none;font-style:normal;font-weight:400;font-variant:normal;text-transform:none;line-height:1;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale}.ctc-icon-whatsapp2:before{content:"\E902"}.ctc-icon-whatsapp:before{content:"\ea93"}