var t;let e="*";"undefined"!=typeof __DEV__&&__DEV__&&(e=sessionStorage.getItem("ctc_debug")||"*",window.ctcDebug=t=>{e="string"==typeof t?t:"*",sessionStorage.setItem("ctc_debug",e)}),"undefined"!=typeof __DEV__&&__DEV__,"undefined"!=typeof document&&document.createElement("div");const _=t=>"string"!=typeof t?t:t.replace(/[&<>"']/g,t=>{switch(t){case"&":return"&amp;";case"<":return"&lt;";case">":return"&gt;";case'"':return"&quot;";case"'":return"&#39;";default:return t}});function n(t){const e=(e,_)=>{const n=t.value("ht_ctc_s99",e);return""===n||null==n?_:n},n=t.cta||"";let i,c="";if("mobile"===t.device){i=t.value("ht_ctc_s99","s99_mobile_img_url")||"",c+=`height: ${e("s99_mobile_img_height","40px")}; `;const _=e("s99_mobile_img_width","40px");""!==_&&(c+=`width: ${_}; `)}else{i=t.value("ht_ctc_s99","s99_dekstop_img_url")||"",c+=`height: ${e("s99_desktop_img_height","50px")}; `;const _=e("s99_desktop_img_width","50px");""!==_&&(c+=`width: ${_}; `)}return""===i&&(i=`${t.pluginUrl}new/inc/assets/img/whatsapp-logo.svg`),`<img class="own-img ctc_s_99 ctc_cta" title="${_(n)}" src="${_(i)}" style="${_(c)}" alt="${_(n)}">`}"undefined"!=typeof DOMParser&&new DOMParser,"undefined"!=typeof document&&document.createElement("textarea"),window.ht_ctc_admin_var,null===(t=window.ht_ctc_admin_var)||void 0===t||null===(t=t.initialSettings)||void 0===t||t.ht_ctc_chat_options;export{n as default};