var t;let e="*";"undefined"!=typeof __DEV__&&__DEV__&&(e=sessionStorage.getItem("ctc_debug")||"*",window.ctcDebug=t=>{e="string"==typeof t?t:"*",sessionStorage.setItem("ctc_debug",e)}),"undefined"!=typeof __DEV__&&__DEV__;const n="undefined"!=typeof document?document.createElement("div"):null,c=("undefined"!=typeof DOMParser&&new DOMParser,"undefined"!=typeof document&&document.createElement("textarea"),window.ht_ctc_admin_var,null===(t=window.ht_ctc_admin_var)||void 0===t||null===(t=t.initialSettings)||void 0===t||t.ht_ctc_chat_options,t=>String(null!=t?t:"").replace(/[<>{}]/g,""));function o(t){var e,o;const r=t.value("ht_ctc_s6","s6_txt_color")||"",_=t.value("ht_ctc_s6","s6_txt_color_on_hover")||"",a=null!==(e=t.value("ht_ctc_s6","s6_txt_decoration"))&&void 0!==e?e:"none",s=null!==(o=t.value("ht_ctc_s6","s6_txt_decoration_on_hover"))&&void 0!==o?o:"underline",l=t.cta||"WhatsApp us";let i="";""!==r&&(i+=`color: ${r}; `),""!==a&&(i+=`text-decoration: ${a}; `);let u="";return""!==_&&(u+=`color: ${c(_)} !important; `),""!==s&&(u+=`text-decoration: ${c(s)} !important; `),`${""!==u?`<style>.ht-ctc .ctc_s_6:hover{${u}}</style>`:""}\n\t<a class="ctc_s_6 ctc_cta" style="${d=i,"string"!=typeof d?d:d.replace(/[&<>"']/g,t=>{switch(t){case"&":return"&amp;";case"<":return"&lt;";case">":return"&gt;";case'"':return"&quot;";case"'":return"&#39;";default:return t}})}">${(t=>{var e;return"string"!=typeof t?t:null!==(e=window.wp)&&void 0!==e&&null!==(e=e.escapeHtml)&&void 0!==e&&e.escapeHTML?window.wp.escapeHtml.escapeHTML(t):n?(n.textContent=t,n.innerHTML):""})(l)}</a>`;var d}export{o as default};