@font-face {
  font-family: 'ccw';
  src:  url(../fonts/ccw.eot);
  src:  url(../fonts/ccw.eot#iefix) format('embedded-opentype'),
    url(../fonts/ccw.ttf) format('truetype'),
    url(../fonts/ccw.woff) format('woff'),
    url(../fonts/ccw.svg#ccw) format('svg');
  font-weight: normal;
  font-style: normal;
}
.ccw_plugin .icon {
  font-family: 'ccw' !important;
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.icon-whatsapp2:before {
  content: "\E902";
}
.icon-brand:before {
  content: "\E901";
  color: #25d366;
}
.icon-send:before {
  content: "\E900";
}
.icon-whatsapp:before {
  content: "\EA93";
}
div.ccw_plugin,
.inline {
  display: inline; }
.inline-block {
  display: inline-block; }
.chatbot {
  position: fixed;
  z-index: 99999999; }
.img-icon {
  height: 48px; }
.nofocus:focus {
  outline: none; }
.pointer {
  cursor: pointer; }
.sc_item {
  z-index: 99; }
.style-3-sc {
  height: 20px; }
.style-9-sc {
  height: 20px; }
.img-icon-5 {
  height: 80%;
  vertical-align: middle; }
.img-icon-6 {
  height: 63%;
  vertical-align: middle;
  margin-left: 7px; }
.style-6-img {
  max-height: 40px;
  text-decoration: overline; }
.icon-2 {
  font-size: 2rem; }
.btn_only_style_div_circle {
  border-radius: 50%;
  text-align: center; }
.btn_only_style_div_circle_sc {
  background-color: orange;
  border-radius: 50%;
  height: 48px;
  width: 48px;
  line-height: 48px;
  text-align: center; }
.btn_only_style_div {
  background-color: orange;
  height: 48px;
  width: 48px;
  line-height: 48px;
  text-align: center; }
.style8 span {
  text-transform: none; }
.ccw_plugin .animated {
  animation-duration: 1s;
  animation-fill-mode: both; }
.ccw_plugin .animated.infinite {
  animation-iteration-count: infinite; }
.ccw_plugin .animated.hinge {
  animation-duration: 2s; }
.ccw_plugin .animated.flipOutX,
.ccw_plugin .animated.flipOutY,
.ccw_plugin .animated.bounceIn,
.ccw_plugin .animated.bounceOut {
  animation-duration: .75s; }
@keyframes bounce {
  from, 20%, 53%, 80%, to {
    animation-timing-function: cubic-bezier(0.215, 0.61, 0.355, 1);
    transform: translate3d(0, 0, 0); }
  40%, 43% {
    animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    transform: translate3d(0, -30px, 0); }
  70% {
    animation-timing-function: cubic-bezier(0.755, 0.05, 0.855, 0.06);
    transform: translate3d(0, -15px, 0); }
  90% {
    transform: translate3d(0, -4px, 0); } }
.ccw_plugin .bounce {
  animation-name: bounce;
  transform-origin: center bottom; }
@keyframes flash {
  from, 50%, to {
    opacity: 1; }
  25%, 75% {
    opacity: 0; } }
.ccw_plugin .flash {
  animation-name: flash; }
@keyframes tada {
  from {
    transform: scale3d(1, 1, 1); }
  10%, 20% {
    transform: scale3d(0.9, 0.9, 0.9) rotate3d(0, 0, 1, -3deg); }
  30%, 50%, 70%, 90% {
    transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, 3deg); }
  40%, 60%, 80% {
    transform: scale3d(1.1, 1.1, 1.1) rotate3d(0, 0, 1, -3deg); }
  to {
    transform: scale3d(1, 1, 1); } }
.ccw_plugin .tada {
  animation-name: tada; }
.ccw_plugin .style-4.chip {
  display: inline-block;
  padding-left: 12px;
  padding-right: 12px;
  padding-top: 0px;
  padding-bottom: 0px;
  border-radius: 25px;
  font-size: 13px;
  line-height: 32px;
}
.ccw_plugin .style-4.chip img {
  float: left;
  margin: 0 8px 0 -12px;
  height: 32px;
  width: 32px;
  border-radius: 50%;
}