var t;let e="*";"undefined"!=typeof __DEV__&&__DEV__&&(e=sessionStorage.getItem("ctc_debug")||"*",window.ctcDebug=t=>{e="string"==typeof t?t:"*",sessionStorage.setItem("ctc_debug",e)}),"undefined"!=typeof __DEV__&&__DEV__;const n="undefined"!=typeof document?document.createElement("div"):null,s=t=>{var e;return"string"!=typeof t?t:null!==(e=window.wp)&&void 0!==e&&null!==(e=e.escapeHtml)&&void 0!==e&&e.escapeHTML?window.wp.escapeHtml.escapeHTML(t):n?(n.textContent=t,n.innerHTML):""},c=t=>"string"!=typeof t?t:t.replace(/[&<>"']/g,t=>{switch(t){case"&":return"&amp;";case"<":return"&lt;";case">":return"&gt;";case'"':return"&quot;";case"'":return"&#39;";default:return t}});function i(t){const e=(e,n)=>{const s=t.value("ht_ctc_s5",e);return""===s||null==s?n:s};let n=t.value("ht_ctc_s5","s5_line_1")||"";const i=t.value("ht_ctc_s5","s5_line_2")||"",r=e("s5_line_1_color","#000000"),o=e("s5_line_2_color","#000000"),l=e("s5_background_color","#ffffff"),a=e("s5_border_color","#dddddd");let _=t.value("ht_ctc_s5","s5_img")||"";const d=e("s5_img_height","70px"),p=e("s5_img_width","70px"),g=e("s5_content_height","70px"),h=e("s5_content_width","270px"),f=e("s5_img_position","right"),u=t.cta||"";""===_&&(_=`${t.pluginUrl}new/inc/assets/img/new_style8.jpg`),""===n&&(n=u);const y=t.isRtl?"flex-direction:row-reverse;":"";let m=`height: ${d}; width: ${p}; z-index: 1; `;"right"===f&&(m+="order: 1;");let x="flex-direction: column; justify-content: center; align-items: center; box-sizing: border-box;";return x+=` background-color: ${l}; border: 1px solid ${a}; height: ${g}; width: ${h};  `,"right"===f?x+="margin-right: -4px;":"left"===f&&(x+="margin-left: -4px;"),`<style>.ht-ctc-style-5 .s5_content{display:none}.ht-ctc-style-5 .s5_cta:hover .s5_content{display:flex}.ht-ctc-style-5 .s5_img{box-shadow:2px 5px 10px rgba(0,0,0,.5)}.ht-ctc-style-5 .s5_content{box-shadow:2px 5px 10px rgba(0,0,0,.5);border-radius:5px}.ht-ctc-style-5 .s5_content span{padding:5px;overflow:hidden}.ht-ctc-style-5 .s5_content .heading{font-size:20px}.ht-ctc-style-5 .s5_content .description{font-size:12px}.ht-ctc-style-5 .s5_content.right{animation:1s s5_translate_right}.ht-ctc-style-5 .s5_content.left{animation:1s s5_translate_left}@keyframes s5_translate_right{0%{transform:translateX(55px)}100%{transform:translateX(0)}}@keyframes s5_translate_left{0%{transform:translateX(-55px)}100%{transform:translateX(0)}}</style>\n\t<div class="ht-ctc-style-5 ctc_s_5" style="cursor: pointer;">\n\t\t<div class="s5_cta" style="${c(`display: -ms-flexbox;display: -webkit-flex; display: flex;${y} `)}">\n\t\t\t<img class="s5_img" src="${c(_)}" style="${c(m)}" alt="${c(u)}">\n\t\t\t<div class="s5_content ctc_cta_stick ${c(f)}" style="${c(x)}">\n\t\t\t\t<span class="heading ctc_cta" style="color: ${c(r)}">${s(n)}</span>\n\t\t\t\t<span class="description" style="color: ${c(o)}">${s(i)}</span>\n\t\t\t</div>\n\t\t</div>\n\t</div>`}"undefined"!=typeof DOMParser&&new DOMParser,"undefined"!=typeof document&&document.createElement("textarea"),window.ht_ctc_admin_var,null===(t=window.ht_ctc_admin_var)||void 0===t||null===(t=t.initialSettings)||void 0===t||t.ht_ctc_chat_options;export{i as default};