/* admin css */

.toplevel_page_click-to-chat #wpcontent,
.click-to-chat_page_click-to-chat-greetings #wpcontent,
.click-to-chat_page_click-to-chat-other-settings #wpcontent,
.click-to-chat_page_click-to-chat-customize-styles #wpcontent {
    background-color: #ffffff;
}

/* md related */
.collapsible-header {
    background-color: #fdfdfd;
}

.collapsible-header .dashicons {
    color: #ddd;
}

.collapsible-header .right_icon.dashicons {
    margin-left: auto;
}
/* rtl: left side */
.rtl .collapsible-header .right_icon.dashicons {
    margin-right: auto;
    margin-left: unset;
}
/* rtl: right side */
.rtl .collapsible-header .left_icon.dashicons {
    /* margin-left: auto; */
    margin-right: unset;
}

/* fixed: md. input icon arrow. */
.rtl .select-wrapper .caret {
    right: unset;
    left: 0;
}

.active:not(.have-sub-collapsible) .collapsible-header .dashicons {
    transform: rotate(180deg);
}

.collapsible .dropdown-content li {
    background-color: #ffffff;
}

* {
    scroll-behavior: smooth;
}

/* commons classes styles */
.margin_top_30 {
    margin-top: 30px;
}

.margin_top_20 {
    margin-top: 20px;
}

.m_top_5 {
    margin-top: 5px;
}

.m_side_10 {
    margin-left: 10px;
    margin-right: 10px;
}

.m_side_15 {
    margin-left: 15px;
    margin-right: 15px;
}

.margin_bottom_15 {
    margin-bottom: 15px;
}

.margin_bottom_25 {
    margin-bottom: 25px;
}

.em_1_1 {
    font-size: 1.1em;
}

.em_1_2 {
    font-size: 1.2em;
}

.ht_ctc_show_hide_settings :checked~.dashicons-visibility,
.ht_ctc_show_hide_settings :checked~span .dashicons-visibility,
.ht_ctc_show_hide_settings .show_settings .dashicons-visibility {
    color: green !important;
}

.ht_ctc_show_hide_settings :checked~.dashicons-hidden,
.ht_ctc_show_hide_settings :checked~span .dashicons-hidden,
.ht_ctc_show_hide_settings .hide_settings .dashicons-hidden {
    color: red !important;
}

.show-hide_display-none,
.not_samesettings,
.show_settings,
.hide_settings,
.ctc_greetings_settings,
.ctc_init_display_none {
    display: none;
}

.options .submit {
    position: sticky !important;
    bottom: 1px;
    /* float: right; */
    z-index: 9;
}

.options .submit input {
    letter-spacing: 0.4px;
    padding: 2px 11px;
}

.select_style_selected {
    background-color: #c5c5c5 !important;
}


summary {
    cursor: pointer;
}


/* Editior */
.click-to-chat_page_click-to-chat-greetings .link-target #wp-link-target {
    opacity: 1 !important;
}

.wp-editor-wrap {
    padding-left: 0.75rem;
}

.description.ht_ctc_pro_description {
    /* border-left: 5px solid yellowgreen; */
    border-left: 5px solid lightseagreen;
    padding: 5px 5px 5px 14px;
    margin: 19px 0;
}

.description.ht_ctc_subtitle {
    border-left: 5px solid lightseagreen;
    /* padding: 5px 5px 5px 14px; */
    padding-left: 0.9rem;
    margin: 5px 0;
}

.description.ht_ctc_pro_subtitle {
    border-left: 5px solid darkseagreen;
    /* padding: 5px 5px 5px 14px; */
    padding-left: 0.9rem;
    margin: 5px 0;
}

/* error message */
.description.ht_ctc_error_message {
    color: red;
    font-size: 0.9rem;
    margin-top: 5px;
}

/* .ht_ctc_pro_subtitle_2 {
    text-decoration: underline;
    text-decoration-color: darkseagreen;
} */

.ht_ctc_content_point:before {
    margin: 0px 4px;
    content: "\2022";
}

/* tabs */
.ctc_md_tab {
    border-right: 1px solid #ddd;
    border-bottom: 1px solid #ddd;
    border-left: 1px solid #ddd;
    box-shadow: 0 2px 2px 0 rgb(0 0 0 / 14%), 0 3px 1px -2px rgb(0 0 0 / 12%), 0 1px 5px 0 rgb(0 0 0 / 20%);
    padding: 25px;
}

.tab a {
    color: #000 !important;
}

.tab a.active {
    color: #000 !important;
}

.tabs .indicator {
    background-color: #4f94d4 !important;
}

.tabs a:focus {
    box-shadow: none;
}

.tabs .tab a:focus,
.tabs .tab a:focus.active {
    background-color: #ffffff !important;
}

.tabs.tabs-fixed-width {
    background-color: #ffffff !important;
}

.md_tab {
    scroll-margin-top: 100px;
}


/* desktop - large screens - greater than 1200 */
@media only screen and (min-width: 1201px) {
    .sticky-sidebar {
        position: sticky !important;
        top: 100px;
        float: right;
    }

    .sticky-sidebar .sidebar-content {
        margin-top: 12px;
        margin-left: 80px;
    }


    .ctc_scrollbar {
        height: 86vh;
        overflow-y: auto;
        visibility: hidden;
    }

    .ctc_scrollbar_2,
    .ctc_scrollbar:hover,
    .ctc_scrollbar:focus {
        visibility: visible;
    }

    .ht-ctc-admin-sidebar::-webkit-scrollbar {
        width: 3px;
    }

    .ht-ctc-admin-sidebar::-webkit-scrollbar-track {
        background: #f1f1f1;
    }

    .ht-ctc-admin-sidebar::-webkit-scrollbar-thumb {
        background: #888;
    }

    .ht-ctc-admin-sidebar::-webkit-scrollbar-thumb:hover {
        background: #555;
    }





}